==> sosse-1.11.1.tar.gz: sosse-1.11.1/sosse/sosse_admin.py <==
#!/usr/bin/env python3
# Copyright 2022-2023 Laurent Defert
#
#  This file is part of SOSSE.
#
# SOSSE is free software: you can redistribute it and/or modify it under the terms of the GNU Affero
# General Public License as published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# SOSSE is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even
# the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# See the GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License along with SOSSE.
# If not, see <https://www.gnu.org/licenses/>.

"""Django's command-line utility for administrative tasks."""
import os
import sys
from pathlib import Path


def main():
    os.environ.setdefault('DJANGO_SETTINGS_MODULE', 'sosse.settings')
    try:
        from django.core.management import execute_from_command_line
    except ImportError as exc:
        raise ImportError(
            "Couldn't import Django. Are you sure it's installed and "
            "available on your PYTHONPATH environment variable? Did you "
            "forget to activate a virtual environment?"
        ) from exc

    linkpreview = Path(__file__).parent.parent / 'se/deps/linkpreview'
    sys.path.insert(0, str(linkpreview))
    fake_useragent = Path(__file__).parent.parent / \
        'se/deps/fake-useragent/src'
    sys.path.insert(0, str(fake_useragent))
    execute_from_command_line(sys.argv)


if __name__ == '__main__':
    main()

==> sosse-1.12.2.tar.gz: sosse-1.12.2/sosse/sosse_admin.py <==
#!/usr/bin/env python3
# Copyright 2022-2025 Laurent Defert
#
#  This file is part of SOSSE.
#
# SOSSE is free software: you can redistribute it and/or modify it under the terms of the GNU Affero
# General Public License as published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# SOSSE is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even
# the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# See the GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License along with SOSSE.
# If not, see <https://www.gnu.org/licenses/>.
"""Django's command-line utility for administrative tasks."""

import os
import sys
from pathlib import Path


def main():
    os.environ.setdefault("DJANGO_SETTINGS_MODULE", "sosse.settings")
    try:
        from django.core.management import execute_from_command_line
    except ImportError as exc:
        raise ImportError(
            "Couldn't import Django. Are you sure it's installed and "
            "available on your PYTHONPATH environment variable? Did you "
            "forget to activate a virtual environment?"
        ) from exc

    linkpreview = Path(__file__).parent.parent / "se/deps/linkpreview"
    sys.path.insert(0, str(linkpreview))
    fake_useragent = Path(__file__).parent.parent / "se/deps/fake-useragent/src"
    sys.path.insert(0, str(fake_useragent))
    execute_from_command_line(sys.argv)


if __name__ == "__main__":
    main()
